@@ -4,7 +4,7 @@
 # se encontram em PATH
 esta_instalado(){
     prog=$1
-    echo "Verificando se $prog est instalado ..."
+    echo "Verificando se $prog está instalado ..."
     for caminho in ${PATH//:/ }
         do
             if [ -x "$caminho/$prog" ]; then
@@ -12,7 +12,7 @@ esta_instalado(){
                 return 0
             fi
         done
-    echo "     $prog no foi encontrado"
+    echo "     $prog não foi encontrado"
     return 1
 }
 
@@ -27,7 +27,7 @@ mf_exit(){
 # Saida sem erro
 saida(){
     $DIALOG --clear
-    $DIALOG --msgbox "A instalao NO foi concluda com sucesso." 24 80
+    $DIALOG --msgbox "A instalação NÃO foi concluída com sucesso." 24 80
     $DIALOG --clear
     mf_exit 1
 }
@@ -35,7 +35,7 @@ saida(){
 # Saida por causa de erro
 saida_por_erro(){
     $DIALOG --clear
-    $DIALOG --msgbox "Ocorreu um erro.\n\nA instalao NO foi concluda com sucesso.\n\n$1" 24 80
+    $DIALOG --msgbox "Ocorreu um erro.\n\nA instalação NÃO foi concluída com sucesso.\n\n$1" 24 80
     $DIALOG --clear
     mf_exit 1
 }
@@ -85,7 +85,7 @@ do
 done
 CAMINHOS="$CAMINHOS $(( $CONT + 1 )) Outro"
 
-$DIALOG --menu "Escolha o diretrio para instalar o arquivo de frases" \
+$DIALOG --menu "Escolha o diretório para instalar o arquivo de frases" \
         24 80 15 \
         $CAMINHOS 2> $TMP
 
@@ -95,16 +95,16 @@ $DIALOG --clear
 
 # Se o usuario prefere outro diretorio que nao um dos apresentados,
 # deve-se deixar que ele digite um caminho
-if [ `cat $TMP` = `expr $CONT + 1` ] 
+if [ `cat $TMP` = `expr $CONT + 1` ]
 then
     cat /dev/null > $TMP
     $DIALOG --inputbox \
-       "Digite o diretrio para instalar o arquivo de frases" \
+       "Digite o diretório para instalar o arquivo de frases" \
        24 80 2> $TMP
        echo -e "\ndigitou" >> $TMP
 fi
 
-[ -z `head -n1 $TMP` ] && saida_por_erro "Voc deve especificar o diretrio onde quer instalar o mario_fortunes."
+[ -z `head -n1 $TMP` ] && saida_por_erro "Você deve especificar o diretório onde quer instalar o mario_fortunes."
 
 
 # Se foi escolhido um dos caminhos sugeridos, coloca-se ele em $TMP
@@ -118,12 +118,12 @@ else
     CAMINHO=`head -n1 $TMP`
     echo $CAMINHO > $TMP
 fi
-    
+
 
 # Se o diretorio nao existe, da'-se um jeito
 [ -d `cat $TMP` ] || {
     $DIALOG --clear
-    $DIALOG --menu "O diretrio especificado no existe. Deseja cri-lo?" \
+    $DIALOG --menu "O diretório especificado não existe. Deseja criá-lo?" \
 	    24 80 15 \
 	    1 Sim \
 	    2 Nao \
@@ -134,7 +134,7 @@ fi
     if [ `cat $OPT` = 1 ]
     then
 	mkdir -p `cat $TMP` 2> $ERRO || saida_por_erro "`cat $ERRO`"
-    else 
+    else
 	saida
     fi
 }
@@ -150,11 +150,9 @@ done
 
 # Mensagens finais
 $DIALOG --clear
-$DIALOG --msgbox "A instalao do mario_fortunes foi concluda com sucesso.\n\nVeja o arquivo DICAS para obter idias de como usar o mario_fortunes.\n\nSugestes de frases podem ser enviadas para mario@proxy.furg.br." 24 80
+$DIALOG --msgbox "A instalação do mario_fortunes foi concluída com sucesso.\n\nVeja o arquivo DICAS para obter idéias de como usar o mario_fortunes.\n\nSugestões de frases podem ser enviadas para mario@proxy.furg.br." 24 80
 
 $DIALOG $ALIGN --msgbox "mario_fortunes: (mario.geral)\n\n`fortune $DIR/mario.geral`" 24 80
 
 # Tchau
 mf_exit 0
-
-
